FQE
===================
This module implements the fitted Q evaluation algorithm for offline policy evaluation.

.. code:: python

   from pycfrl import fqe

.. automodule:: pycfrl.fqe
   :members:
   :show-inheritance:
   :special-members: __init__